translate.tools.pydiff

Package translate :: Package tools :: Module pydiff |
[hide private]
[frames] | no frames]

# Module pydiff

source code

diff tool like GNU diff, but lets you have special options that are useful in dealing with PO files

Classes | [hide private]
| DirDiffer generates diffs between directories
| FileDiffer generates diffs between files

Functions | [hide private]
main() main program for pydiff | source code

Variables | [hide private]
| lineterm = ``'``\n``'``

Imports: difflib, optparse, time, os, sys, fnmatch